@@ -1,6 +1,5 @@
 import time  # datetime may have more precision
 
-from .clients.graphite import Statsd
 from .clients.default import Default
 from .clients.slack import SlackTelemeter
 from .clients.pagerduty import PagerDutyTelemeter
@@ -11,7 +10,6 @@ __all__ = [
 ]
 
 SERVICES = {
-    'statsd': Statsd,
     'default': Default
 }
 
